/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
module GNOME {
	interface capplet {
                void try(in long id);
                boolean revert(in long id);
                boolean ok (in long id);
                void cancel (in long id);
                void help(in long id);
                void new_multi_capplet (in long id, in long newid, in unsigned long newxid, in long newcapid);
                void page_hidden(in long id);
                void page_shown(in long id);
	};
	interface control_center {
                long register_capplet (in long id, in capplet cap);
                void state_changed (in long id, in boolean undoable);
                void register_capplet_new (in capplet cap, in string name, in long capid, out unsigned long xid, out long newid);
                void show_control_center ();
		void changes_are_immediate (in long id);
	};
};
